#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bindings-uname
version:              0.1
visibility:           public
id:                   bindings-uname-0.1-ELiA51hyKT1CPQhIIYs51f
key:                  bindings-uname-0.1-ELiA51hyKT1CPQhIIYs51f
license:              LicenseRef-PublicDomain
maintainer:           PHO <pho at cielonegro.org>
author:               PHO <pho at cielonegro.org>
stability:            Experimental
synopsis:             Low-level binding to POSIX uname(3)
description:
    This is a low-level binding to POSIX uname(3)
    function. Perhaps it shoule be part of unix package.

category:             FFI, System
abi:                  73dd9e2bd9b6aad8cb6e80a00dfa81df
exposed:              True
exposed-modules:      Bindings.Uname
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bindings-uname-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bindings-uname-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bindings-uname-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bindings-uname
hs-libraries:         HSbindings-uname-0.1-ELiA51hyKT1CPQhIIYs51f
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-bindings-uname/html/bindings-uname.haddock

haddock-html:         /usr/share/doc/haskell-bindings-uname/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

